@@ -71,15 +71,20 @@ class TflAppMain(QtGui.QMainWindow):
         
 
     def doGetmeHome(self):
+        self.showBusyIndicator()
         currentLoc = self.getCurrentPCode()
         self.dest = self.ui.lineEditHomePC.text()
+        self.progress.setLabelText("Opening Journey Planner in external Browser")
         print "start: " + currentLoc +  "& dest:" + self.dest
         finalUrl = PLANNER_URL_PART1 + currentLoc + PLANNER_URL_PART2 + self.dest + PLANNER_URL_PART3
         QtGui.QDesktopServices.openUrl(QtCore.QUrl(finalUrl, QtCore.QUrl.TolerantMode))
+        self.progress.destroy(True, True)
 
     def getCurrentPCode(self):
+        self.progress.setLabelText("Getting approx location via cellID")
         self.getCurrentLoc()
         if( (51.286829 <= self.curLocLat <= 51.69232322) and (-0.510350 <= self.curLocLong <= 0.334030) ):
+            self.progress.setLabelText("Geolocating postcode")
             pCode = self.getCurrentPCodeFromLoc()
         else:
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Does not work outside London - Just a test route for you"')
@@ -125,6 +130,21 @@ class TflAppMain(QtGui.QMainWindow):
         self.settings.setValue("home_Pcode", self.ui.lineEditHomePC.text() )
 
 
+
+    def showBusyIndicator(self):
+        self.progress = QtGui.QProgressDialog(self)
+        self.progress.setWindowModality(QtCore.Qt.WindowModal)
+        self.progress.setAutoReset(True)
+        self.progress.setAutoClose(True)
+        self.progress.setMinimum(0)
+        self.progress.setMaximum(0)
+        self.progress.resize(800,100)
+        self.progress.setWindowTitle("Hang on....")
+        self.progress.setLabelText("Initial setup")
+        self.progress.show()
+
+
+
     def showAbout(self):
         aboutString = "Tfl App: v" + CURRENTVERSION + "\nGirish Gopi (maemo@gman.me.uk)\nMany thanks to all of t.m.o (& w.m.o) and the gaffa"
         QtGui.QMessageBox.information(self, "About Tfl App", aboutString)
@@ -140,9 +160,10 @@ class TflAppMain(QtGui.QMainWindow):
         if device.fix:
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
                 print "lat = %f, long = %f" % device.fix[4:6]
-                self.curLocLat = device.fix[4]
-                self.curLocLong = device.fix[5]
-                data.stop()
+                if((device.fix[4] != 55.3) and (device.fix[5] != 0) ):
+                  self.curLocLat = device.fix[4]
+                  self.curLocLong = device.fix[5]
+                  data.stop()
 
     def on_stop(self, control, data):
         print "quitting"
