@@ -14,7 +14,7 @@ class TubeMapDisplay(QtGui.QMainWindow):
         self.pic = QtGui.QLabel(self)
         self.pic.setGeometry(0,0,800,400)
         #self.pic.setPixmap(QtGui.QPixmap(os.getcwd() + "/tubemap.gif"))
-        self.pic.setPixmap(QtGui.QPixmap("/opt/tflapp/tubemap.gif"))
+        self.pic.setPixmap(QtGui.QPixmap("/opt/tflapp/tubemap.png"))
         self.scrollArea = QtGui.QScrollArea(self)
         self.scrollArea.setWidget(self.pic)
         self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 400))
